OpenFermion-ProjectQ
====================

.. image:: https://travis-ci.org/quantumlib/OpenFermion-ProjectQ.svg?branch=develop
    :target: https://travis-ci.org/quantumlib/OpenFermion-ProjectQ

.. image:: https://coveralls.io/repos/github/quantumlib/OpenFermion-ProjectQ/badge.svg?branch=develop
    :target: https://coveralls.io/github/quantumlib/OpenFermion-ProjectQ?branch=develop

.. image:: https://badge.fury.io/py/openfermionprojectq.svg
    :target: https://badge.fury.io/py/openfermionprojectq

`OpenFermion <http://openfermion.org>`_ is an open source package for compiling and analyzing quantum algorithms that simulate fermionic systems.
This plugin library allows the circuit simulation and compilation package `ProjectQ <https://projectq.ch>`_ to interface with OpenFermion.

Getting started
---------------

To start using OpenFermion-ProjectQ, first install `OpenFermion <http://openfermion.org>`_ and `ProjectQ <https://projectq.ch>`_.
Then, clone this git repo, change directory to the top level folder and run:

.. code-block:: bash

  python -m pip install -e .

Alternatively, one can install the last major release with the command

.. code-block:: bash

  python -m pip install openfermionprojectq

Authors
-------

`Ryan Babbush <http://ryanbabbush.com>`__ (Google),
`Jarrod McClean <http://jarrodmcclean.com>`__ (Google),
Ian Kivlichan (Harvard),
Damian Steiger (ETH Zurich),
Wei Sun (Google),
Craig Gidney (Google),
Thomas Haner (ETH Zurich),
Hannah Sim (Harvard),
Vojtech Havlicek (Oxford),
Kanav Setia (Dartmouth),
Nicholas Rubin (Rigetti),
Matthew Neeley (Google) and
Dave Bacon (Google).

Questions?
----------

If you have any other questions, please contact help@openfermion.org.

Disclaimer
----------

Copyright 2017 The OpenFermion Developers.
This is not an official Google product.
